@@ -2,15 +2,15 @@ built_modules = list(name for name in
     "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;Positioning;Location;Qml;Quick;QuickWidgets;RemoteObjects;Scxml;Script;ScriptTools;Sensors;TextToSpeech;Charts;Svg;DataVisualization;UiTools;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
 
-shiboken_library_soversion = str(5.12)
-pyside_library_soversion = str(5.12)
+shiboken_library_soversion = str(5.13)
+pyside_library_soversion = str(5.13)
+
+version = "5.13.0"
+version_info = (5, 13, 0, "", "")
+
+__build_date__ = '2019-06-27T09:54:14+00:00'
 
-version = "5.12.4"
-version_info = (5, 12, 4, "", "")
 
-__build_date__ = '2019-06-27T12:40:20+00:00'
-__build_commit_date__ = '2019-06-27T12:38:55+00:00'
-__build_commit_hash__ = '419e09b3bea9e01cc4fed7f9d14de1ba7f9032c2'
 
 
 
